"""
For detailed documentation of the Osiris Level 1 services module see the external documentation.
"""
import os
import os.path
import sys
from . import osl1
from . import osl1helperfuncs 
  
#-----------------------------------------------------------------------------------------
#                       Start of main init scrip
#  This initializes the Pratmo module to use the SasktranIF registry. This is used to store
#  cached aerosol parameters etc. Sasktranif is imported as part of this module to enforce
#  the dependency pratmo has on that module.
#-----------------------------------------------------------------------------------------

dirname = os.path.join( sys.exec_prefix,'share', 'usask-arg','registry','sasktranif')
osl1.OSIRISLEVEL1_IFSetRegistryDirectory(dirname)
filename = dirname + os.sep + 'globalkey.yaml'
if not os.path.exists(filename):
   print('The SasktranIF registry file ', filename, ' used by OSIRIS Level 1 services does not exist. Thats odd and probably means some configuration has changed since this code was written. Thats NOT GOOD for Pratmo!')

#-------------- FUNCTION WRAPPERS ------------------

OSSolarAngles  = osl1helperfuncs.OSSolarAngles
OSTangentPoint = osl1helperfuncs.OSTangentPoint
LoadScanOS     = osl1helperfuncs.LoadScanOS
LoadMjdOS      = osl1helperfuncs.LoadMjdOS
